summaryrefslogtreecommitdiffstats
path: root/ksirc/puke/controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/puke/controller.h')
-rw-r--r--ksirc/puke/controller.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/ksirc/puke/controller.h b/ksirc/puke/controller.h
index 5daa1629..5d22cef3 100644
--- a/ksirc/puke/controller.h
+++ b/ksirc/puke/controller.h
@@ -27,7 +27,7 @@ typedef struct {
TQString server;
bool writeable;
TQSocketNotifier *sr,*sw;
-} fdStatus;
+} fdtqStatus;
struct commandStruct {
@@ -80,8 +80,9 @@ private:
class PukeController : public PObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- PukeController(TQString socket = "", TQObject *parent=0, const char *name=0);
+ PukeController(TQString socket = "", TQObject *tqparent=0, const char *name=0);
virtual ~PukeController();
bool running;
@@ -136,7 +137,7 @@ private:
int iListenFd;
bool bClosing; // Set true if we are closing, we don't try and close twice at the same time.
TQSocketNotifier *qsnListen;
- TQIntDict<fdStatus> qidConnectFd;
+ TQIntDict<fdtqStatus> qidConnectFd;
/**
* Controller ID is defined as 1
@@ -168,7 +169,7 @@ private:
/**
* Create new Widget, returns new iWinId for it.
* Takes server fd and parent winid, and type as arguments
*/
widgetId createWidget(widgetId wI, PukeMessage *pm);
@@ -168,7 +169,7 @@ private:
/**
* Create new Widget, returns new iWinId for it.
- * Takes server fd and parent winid, and type as arguments
+ * Takes server fd and tqparent winid, and type as arguments
*/
widgetId createWidget(widgetId wI, PukeMessage *pm);